@@ -26,7 +26,7 @@ def errors():
         'The password has expired and must be renewed.': SamlPasswordExpired,
         'Account expired.': SamlAccountExpired,  # simplesamlphp
         'The account has expired.': SamlAccountExpired,  # keycloak
-        'The authentication has failed, please login again.': SamlAuthenticationFailed,  # keycloak
+        'Invalid username or password.': SamlAuthenticationFailed,  # keycloak
         'Incorrect username or password.': SamlAuthenticationFailed,  # simplesamlphp
         'Account not verified.': SamlAccountNotVerified,
         'Changing password failed.': SamlPasswordChangeFailed,  # simplesamlphp
